#
# spec file for package ColorFull
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define shlib lib%{name}0
Name:           ColorFull
Version:        1.1
Release:        2.3
Summary:        C++ library for calculations in QCD (SU(Nc)) color space
License:        GPL-2.0-only
Group:          Productivity/Scientific/Physics
URL:            http://colorfull.hepforge.org/
Source0:        http://colorfull.hepforge.org/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
# PATCH-FIX-UPSTREAM ColorFull-install-pkgconfig-file.patch badshah400@gmail.com -- Add a pkgconfig file and modify the autotool files to install it to an appropriate location
Patch2:         ColorFull-install-pkgconfig-file.patch
BuildRequires:  gcc-c++
BuildRequires:  libtool
BuildRequires:  pkgconfig
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
%{name} is a C++ library for calculations in QCD (SU(Nc)) color space. It can
* Square any QCD color amplitude and calculate any interference.
* Create a trace type basis for any number of quarks and gluons.
* Read in and write out color bases.
* Calculate scalar product matrices, i.e., the matrices of scalar products
  between the basis vectors.
* Describe the effect of gluon exchange, including calculating the color
  soft anomalous dimension matrices.
* Describe the effect of gluon emission.
* Be interfaced to Herwig++ (>= 2.7) via Matchbox.

%package -n %{shlib}
Summary:        C++ library for calculations in QCD (SU(Nc)) color space
Group:          System/Libraries

%description -n %{shlib}
%{name} is a C++ library for calculations in QCD (SU(Nc)) color space. It can
* Square any QCD color amplitude and calculate any interference.
* Create a trace type basis for any number of quarks and gluons.
* Read in and write out color bases.
* Calculate scalar product matrices, i.e., the matrices of scalar products
  between the basis vectors.
* Describe the effect of gluon exchange, including calculating the color
  soft anomalous dimension matrices.
* Describe the effect of gluon emission.
* Be interfaced to Herwig++ (>= 2.7) via Matchbox.

This package provides the shared library for %{name}.

%package devel
Summary:        Development files for ColorFull, a library for calculations in QCD color space
Group:          Development/Libraries/C and C++
Requires:       %{shlib} = %{version}

%description devel
%{name} is a C++ library for calculations in QCD (SU(Nc)) color space. It can
* Square any QCD color amplitude and calculate any interference.
* Create a trace type basis for any number of quarks and gluons.
* Read in and write out color bases.
* Calculate scalar product matrices, i.e., the matrices of scalar products
  between the basis vectors.
* Describe the effect of gluon exchange, including calculating the color
  soft anomalous dimension matrices.
* Describe the effect of gluon emission.
* Be interfaced to Herwig++ (>= 2.7) via Matchbox.

This package provides the headers and source files needed for developing applications using %{name}.

%prep
%autosetup -p1

%build
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
make %{?_smp_mflags} DESTDIR=%{buildroot} install

find %{buildroot} -type f -name "*.la" -delete -print

# DON'T INSTALL TEST/EXAMPLE BINARIES, PKG THE CODES AS DOC INSTEAD
rm %{buildroot}%{_bindir}/{ColorFull_test,ColorPlay}

# MOVE LIBS INSTALLED TO STD LIBDIR
mv %{buildroot}%{_libdir}/%{name}/* %{buildroot}%{_libdir}/
rm -fr %{buildroot}%{_libdir}/%{name}/

%post -n %{shlib} -p /sbin/ldconfig
%postun -n %{shlib} -p /sbin/ldconfig

%files -n %{shlib}
%defattr(-,root,root)
%{_libdir}/*.so.*

%files devel
%defattr(-,root,root)
%doc AUTHORS ChangeLog README COPYING
%doc Test/*.cc Examples/*.cc
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{name}.pc
%{_includedir}/%{name}/

%changelog
* Wed May 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Use %%autosetup macro: allows us to eliminate usage of deprecated
  %%patchN syntax.
* Wed Aug  2 2017 badshah400@gmail.com
- Update to version 1.1:
  * Added functions split_gluon, default_parton_numbers,
    rename_partons in Col_functions. These functions are used for
    g -> qqbar splitting.
  * Removed Matchbox interface to Herwig, since ColorFull along
    with the interface, is shipped with Herwig from version 7.0.
  * Included various minor updates from Herwig version.
- Changes from version 1.0:
  * Fixed Monomial.h to build using --std=c++11 and --std=c++14.
  * Fixed all warnings appearing with -Wextra for g++ and clang
    using --std=c++11 and c++14. This required removing some
    arguments in private functions.
- Move shared libs to standard libdir from libdir/name; this
  makes the package compliant with openSUSE shared lib packaging
  policy, and no longer requires the installation of a conf file.
- Drop patches incorporated or otherwise fixed upstream:
  * ColorFull-monomial-conjugate-assignment.patch
  * ColorFull-monomial-illegal-or-usage.patch
* Mon Oct 31 2016 jengelh@inai.de
- Update descriptions and RPM groups
* Sun Oct 30 2016 badshah400@gmail.com
- Fix Libs and Cflags in the pkgconfig file.
* Fri Oct 28 2016 badshah400@gmail.com
- Initial package.
- Add patches to fix syntactical errors and get the package
  building:
  * ColorFull-monomial-conjugate-assignment.patch: Fix an
    incorrect assignment syntax.
  * ColorFull-monomial-illegal-or-usage.patch: Fix the usage of
    "or" by using appropriate parenthesis around the operands.
  * ColorFull-install-pkgconfig-file.patch: Add a pkgconfig file
    and modify the autotool files to install it to an
    appropriate location
- Add rpmlintrc file to suppress false warning about spelling
  errors in description tag coming from the package name
  (ColorFull, not colorful).
